==> mule-agent-rest-client-4.0.0-rc-sources.jar: org/mule/tooling/agent/rest/client/tooling/applications/Applications.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.tooling.agent.rest.client.tooling.applications;

import static javax.ws.rs.core.MediaType.APPLICATION_JSON_TYPE;
import static javax.ws.rs.core.MediaType.APPLICATION_OCTET_STREAM_TYPE;
import static javax.ws.rs.core.Response.Status.Family.SUCCESSFUL;
import static org.mule.tooling.agent.rest.client.exceptions.ToolingServiceAPIException.newToolingServiceAPIException;
import static org.mule.tooling.agent.rest.client.tooling.Tooling.VERBOSE_QUERY_PARAM;
import org.mule.tooling.agent.rest.client.exceptions.ToolingServiceAPIException;
import org.mule.tooling.agent.rest.client.tooling.applications.applicationId.ApplicationId;
import org.mule.tooling.agent.rest.client.tooling.applications.applicationLogging.ApplicationLogging;
import org.mule.tooling.agent.rest.client.tooling.applications.applicationName.ApplicationName;
import org.mule.tooling.agent.rest.client.tooling.applications.model.ApplicationsGETResponse;
import org.mule.tooling.agent.rest.client.tooling.applications.model.ApplicationsPUTBody;
import org.mule.tooling.agent.rest.client.tooling.applications.model.ApplicationsPUTResponse;

import java.io.InputStream;
import java.util.List;

import javax.ws.rs.client.Client;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.GenericType;
import javax.ws.rs.core.Response;

/**
 * Application web resource.
 *
 * @since 4.0
 */
public class Applications {

  private String baseUrl;
  private Client client;

  public Applications(String baseUrl, Client client) {
    this.baseUrl = (baseUrl + "/applications");
    this.client = client;
  }

  private Client getClient() {
    return this.client;
  }

  private String getBaseUri() {
    return baseUrl;
  }

  /**
   * GET operation to retrieve the list of applications deployed.
   *
   * @return {@link List} of {@link ApplicationsGETResponse}s
   * @throws ToolingServiceAPIException if there was an error.
   */
  public List<ApplicationsGETResponse> get() {
    WebTarget target = this.getClient().target(getBaseUri());
    final javax.ws.rs.client.Invocation.Builder invocationBuilder = target.request(APPLICATION_JSON_TYPE);
    Response response = invocationBuilder.get();
    if (response.getStatusInfo().getFamily() != SUCCESSFUL) {
      throw newToolingServiceAPIException(response);
    }
    return response.readEntity(new GenericType<List<ApplicationsGETResponse>>() {

    });
  }

  /**
   * PUT operation to deploy a tooling application not compressed.
   *
   * @param body                  {@link ApplicationsPUTBody} request body.
   * @param verboseErrorsEnabled  flag that defines if it has to be verbose the response in case of errors/failures.
   * @return {@link ApplicationsPUTResponse} for the deployed application.
   * @throws ToolingServiceAPIException if there was an error.
   */
  public ApplicationsPUTResponse put(ApplicationsPUTBody body, boolean verboseErrorsEnabled) {
    WebTarget target = this.getClient().target(getBaseUri());
    target = target.queryParam(VERBOSE_QUERY_PARAM, verboseErrorsEnabled);
    final javax.ws.rs.client.Invocation.Builder invocationBuilder = target.request(APPLICATION_JSON_TYPE);
    Response response = invocationBuilder.put(javax.ws.rs.client.Entity.json(body));
    if (response.getStatusInfo().getFamily() != SUCCESSFUL) {
      throw newToolingServiceAPIException(response);
    }
    return response.readEntity(ApplicationsPUTResponse.class);
  }

  /**
   * PUT operation to deploy a tooling application compressed from an {@link InputStream}.
   *
   * @param body {@link InputStream} to read the content of the application zipped.
   * @param verboseErrorsEnabled  flag that defines if it has to be verbose the response in case of errors/failures.
   * @return {@link ApplicationsPUTResponse} for the deployed application.
   * @throws ToolingServiceAPIException if there was an error.
   */
  public ApplicationsPUTResponse put(InputStream body, boolean verboseErrorsEnabled) {
    WebTarget target = this.getClient().target(getBaseUri());
    target = target.queryParam(VERBOSE_QUERY_PARAM, verboseErrorsEnabled);
    final javax.ws.rs.client.Invocation.Builder invocationBuilder = target.request(APPLICATION_JSON_TYPE);
    Response response = invocationBuilder.put(javax.ws.rs.client.Entity.entity(body, APPLICATION_OCTET_STREAM_TYPE));
    if (response.getStatusInfo().getFamily() != SUCCESSFUL) {
      throw newToolingServiceAPIException(response);
    }
    return response.readEntity(ApplicationsPUTResponse.class);
  }

  /**
   * Access to the application resource.
   *
   * @param applicationId the identifier of the application.
   * @return {@link ApplicationId} to operate with.
   */
  public final ApplicationId applicationId(String applicationId) {
    return new ApplicationId(getBaseUri(), getClient(), applicationId);
  }

  /**
   * Access to the application resource.
   *
   * @param applicationName the name of the application.
   * @return {@link ApplicationId} to operate with.
   */
  public final ApplicationName applicationName(String applicationName) {
    return new ApplicationName(getBaseUri(), getClient(), applicationName);
  }

  /**
   *
   * @return {@link ApplicationLogging} to operate with.
   */
  public final ApplicationLogging logging() {
    return new ApplicationLogging(getBaseUri(), getClient());
  }
}

==> mule-agent-rest-client-4.2.2-rc3-sources.jar: org/mule/tooling/agent/rest/client/tooling/applications/Applications.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.tooling.agent.rest.client.tooling.applications;

import static javax.ws.rs.core.MediaType.APPLICATION_JSON_TYPE;
import static javax.ws.rs.core.MediaType.APPLICATION_OCTET_STREAM_TYPE;
import static javax.ws.rs.core.Response.Status.Family.SUCCESSFUL;
import static org.glassfish.jersey.client.ClientProperties.READ_TIMEOUT;
import static org.mule.tooling.agent.rest.client.exceptions.ToolingServiceAPIException.newToolingServiceAPIException;
import static org.mule.tooling.agent.rest.client.tooling.Tooling.VERBOSE_QUERY_PARAM;

import org.mule.tooling.agent.rest.client.exceptions.ToolingServiceAPIException;
import org.mule.tooling.agent.rest.client.tooling.applications.applicationId.ApplicationId;
import org.mule.tooling.agent.rest.client.tooling.applications.applicationName.ApplicationName;
import org.mule.tooling.agent.rest.client.tooling.applications.model.ApplicationsGETResponse;
import org.mule.tooling.agent.rest.client.tooling.applications.model.ApplicationsPUTBody;
import org.mule.tooling.agent.rest.client.tooling.applications.model.ApplicationsPUTResponse;

import java.io.InputStream;
import java.util.List;

import javax.ws.rs.client.Client;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.GenericType;
import javax.ws.rs.core.Response;

/**
 * Application web resource.
 *
 * @since 4.0
 */
public class Applications {

  private static final String DOMAIN_NAME_QUERY_PARAM = "domainName";
  private static final String ARTIFACT_ID = "artifactId";

  private String baseUrl;
  private Client client;

  public Applications(String baseUrl, Client client) {
    this.baseUrl = (baseUrl + "/applications");
    this.client = client;
  }

  private Client getClient() {
    return this.client;
  }

  private String getBaseUri() {
    return baseUrl;
  }

  /**
   * GET operation to retrieve the list of applications deployed.
   *
   * @param verboseErrorsEnabled  flag that defines if it has to be verbose the response in case of errors/failures.
   * @param readTimeout           read timeout in milliseconds
   * @return {@link List} of {@link ApplicationsGETResponse}s
   * @throws ToolingServiceAPIException if there was an error.
   */
  public List<ApplicationsGETResponse> get(boolean verboseErrorsEnabled, int readTimeout) throws ToolingServiceAPIException {
    WebTarget target = this.getClient().target(getBaseUri());
    target = target.queryParam(VERBOSE_QUERY_PARAM, verboseErrorsEnabled);
    final javax.ws.rs.client.Invocation.Builder invocationBuilder = target.request(APPLICATION_JSON_TYPE);
    if (readTimeout > 0) {
      invocationBuilder.property(READ_TIMEOUT, readTimeout);
    }
    Response response = invocationBuilder.get();
    if (response.getStatusInfo().getFamily() != SUCCESSFUL) {
      throw newToolingServiceAPIException(response);
    }
    return response.readEntity(new GenericType<List<ApplicationsGETResponse>>() {

    });
  }

  /**
   * PUT operation to deploy a tooling application not compressed.
   *
   * @param body                  {@link ApplicationsPUTBody} request body.
   * @param verboseErrorsEnabled  flag that defines if it has to be verbose the response in case of errors/failures.
   * @param readTimeout           read timeout in milliseconds
   * @return {@link ApplicationsPUTResponse} for the deployed application.
   * @throws ToolingServiceAPIException if there was an error.
   */
  public ApplicationsPUTResponse put(ApplicationsPUTBody body, boolean verboseErrorsEnabled, int readTimeout)
      throws ToolingServiceAPIException {
    WebTarget target = this.getClient().target(getBaseUri());
    target = target.queryParam(VERBOSE_QUERY_PARAM, verboseErrorsEnabled);
    final javax.ws.rs.client.Invocation.Builder invocationBuilder = target.request(APPLICATION_JSON_TYPE);
    if (readTimeout > 0) {
      invocationBuilder.property(READ_TIMEOUT, readTimeout);
    }
    Response response = invocationBuilder.put(javax.ws.rs.client.Entity.json(body));
    if (response.getStatusInfo().getFamily() != SUCCESSFUL) {
      throw newToolingServiceAPIException(response);
    }
    ApplicationsPUTResponse applicationsPUTResponse = response.readEntity(ApplicationsPUTResponse.class);
    response.close();
    return applicationsPUTResponse;
  }

  /**
   * PUT operation to deploy a tooling application compressed from an {@link InputStream}.
   *
   * @param body {@link InputStream} to read the content of the application zipped.
   * @param verboseErrorsEnabled  flag that defines if it has to be verbose the response in case of errors/failures.
   * @param readTimeout           read timeout in milliseconds
   * @return {@link ApplicationsPUTResponse} for the deployed application.
   * @throws ToolingServiceAPIException if there was an error.
   */
  public ApplicationsPUTResponse put(InputStream body, String artifactId, boolean verboseErrorsEnabled, int readTimeout)
      throws ToolingServiceAPIException {
    WebTarget target = this.getClient().target(getBaseUri());
    target = target.queryParam(ARTIFACT_ID, artifactId);
    target = target.queryParam(VERBOSE_QUERY_PARAM, verboseErrorsEnabled);
    final javax.ws.rs.client.Invocation.Builder invocationBuilder = target.request(APPLICATION_JSON_TYPE);
    if (readTimeout > 0) {
      invocationBuilder.property(READ_TIMEOUT, readTimeout);
    }
    Response response = invocationBuilder.put(javax.ws.rs.client.Entity.entity(body, APPLICATION_OCTET_STREAM_TYPE));
    if (response.getStatusInfo().getFamily() != SUCCESSFUL) {
      throw newToolingServiceAPIException(response);
    }
    return response.readEntity(ApplicationsPUTResponse.class);
  }

  /**
   * PUT operation to deploy a tooling application compressed from an {@link InputStream}.
   *
   * @param body {@link InputStream} to read the content of the application zipped.
   * @param domainName {@link String} referencing the domain name already deployed to be linked by this application.
   * @param verboseErrorsEnabled  flag that defines if it has to be verbose the response in case of errors/failures.
   * @param readTimeout           read timeout in milliseconds
   * @return {@link ApplicationsPUTResponse} for the deployed application.
   * @throws ToolingServiceAPIException if there was an error.
   */
  public ApplicationsPUTResponse put(InputStream body, String artifactId, String domainName, boolean verboseErrorsEnabled,
                                     int readTimeout)
      throws ToolingServiceAPIException {
    WebTarget target = this.getClient().target(getBaseUri());
    target = target.queryParam(ARTIFACT_ID, artifactId);
    target = target.queryParam(DOMAIN_NAME_QUERY_PARAM, domainName);
    target = target.queryParam(VERBOSE_QUERY_PARAM, verboseErrorsEnabled);
    final javax.ws.rs.client.Invocation.Builder invocationBuilder = target.request(APPLICATION_JSON_TYPE);
    if (readTimeout > 0) {
      invocationBuilder.property(READ_TIMEOUT, readTimeout);
    }
    Response response = invocationBuilder.put(javax.ws.rs.client.Entity.entity(body, APPLICATION_OCTET_STREAM_TYPE));
    if (response.getStatusInfo().getFamily() != SUCCESSFUL) {
      throw newToolingServiceAPIException(response);
    }
    return response.readEntity(ApplicationsPUTResponse.class);
  }

  /**
   * Access to the application resource.
   *
   * @param applicationId the identifier of the application.
   * @return {@link ApplicationId} to operate with.
   */
  public final ApplicationId applicationId(String applicationId) {
    return new ApplicationId(getBaseUri(), getClient(), applicationId);
  }

  /**
   * Access to the application resource.
   *
   * @param applicationName the name of the application.
   * @return {@link ApplicationId} to operate with.
   */
  public final ApplicationName applicationName(String applicationName) {
    return new ApplicationName(getBaseUri(), getClient(), applicationName);
  }

}
